/*!
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/* tslint:disable:unified-signatures */

import { EventEmitter } from 'events';
import Segment from '../trace/context/Segment';

declare interface SkyWalkingEventEmitter {
  on(event: 'segment-finished', listener: (segment: Segment) => void): this;
  on(event: 'segments-sent', listener: () => void): this;
}

class SkyWalkingEventEmitterImpl extends EventEmitter {}

export const emitter: SkyWalkingEventEmitterImpl = new SkyWalkingEventEmitterImpl();
